@@ -76,41 +76,38 @@ class Application(Entity):
                                                     data={'manifestSource': 'upload', 'name': name})
         app = Application(organization, resp.json()['id'])
         app.manifest = manifest
+        log.info("Application %s created (%s)" % (name, app.applicationId))
         return app
 
     def delete(self):
-        log.info("Removing application: %s" % self.name)
+        log.info("Removing application: %s (%s)" % (self.name, self.applicationId))
         router.delete_application(org_id=self.organizationId, app_id=self.applicationId)
         return True
 
     def update(self, **kwargs):
         if kwargs.get('manifest'):
             self.upload(kwargs.pop('manifest'))
-        log.info("Updating application: %s" % self.name)
+        log.info("Updating application: %s (%s)" % (self.name, self.applicationId))
 
         data = json.dumps(kwargs)
         resp = router.put_application(org_id=self.organizationId, app_id=self.applicationId, data=data)
         return resp.json()
 
-    def clean(self, timeout=3):
-        for ins in self.instances:
-            st = ins.status
-            if st not in ['Destroyed', 'Destroying', 'Launching', 'Executing']: # Tests could fail and we can get any state here
-                log.info("Destroying instance %s" % ins.name)
-                ins.delete()
-                assert ins.destroyed(timeout=timeout)
-                self.instances.remove(ins)
+    def clean(self, timeout=[7, 1, 1.5]):
+        instances = self.instances
+        log.info("Cleaning application %s (%s)" % (self.name, self.applicationId))
+        for ins in instances:
+            if ins.status not in ['Destroyed', 'Destroying']:
+                ins.destroy()
+
+        @retry(*timeout, retry_exception=AssertionError)
+        def eventually_clean():
+            for ins in instances:
+                assert ins.status == 'Destroyed'
+        eventually_clean()
 
         for rev in self.revisions:
-            self.revisions.remove(rev)
             rev.delete()
-
-        @retry(5, 1 , 2 , AssertionError)
-        def eventually_clean():
-            for ins in self.instances:
-                assert ins.status == 'Destroyed'
-
-        eventually_clean()
         return True
 
     def json(self):
@@ -136,19 +133,29 @@ class Application(Entity):
     def list_revisions_json(self):
         return self.json()['revisions']
 
-    def create_revision(self, name, instance, parameters=[], version=None):
+    def create_revision(self, name, instance=None, parameters=[], version=None):
         if not version:
             version=self.get_manifest()['manifestVersion']
-        payload = json.dumps({ 'name': name,
-                    'parameters': parameters,
-                    'submoduleRevisions': {},
-                    'returnValues': [],
-                    'applicationId': self.applicationId,
-                    'applicationName': self.name,
-                    'version': version,
-                    'instanceId': instance.instanceId})
-        resp = router.post_revision(org_id=self.organizationId, app_id=self.applicationId, data=payload)
-        return self.get_revision(id=resp.json()['id'])
+        if instance:
+            payload = json.dumps({ 'name': name,
+                        'parameters': parameters,
+                        'submoduleRevisions': {},
+                        'returnValues': [],
+                        'applicationId': self.applicationId,
+                        'applicationName': self.name,
+                        'version': version,
+                        'instanceId': instance.instanceId})
+            resp = router.post_revision(org_id=self.organizationId, app_id=self.applicationId, data=payload)
+            return self.get_revision(id=resp.json()['id'])
+        else:
+
+            payload = json.dumps({ 'name': name,
+                            'parameters': parameters,
+                            'submodules': [],
+                            'applicationId': self.applicationId,
+                            'version': version,})
+            resp = router.post_revision_fs(org_id=self.organizationId, app_id=self.applicationId, data=payload)
+            return self.get_revision(id=resp.json()['id'])
 
     def delete_revision(self, id):
         self.get_revision(id).delete()
@@ -159,7 +166,7 @@ class Application(Entity):
         return router.post_application_refresh(org_id=self.organizationId, app_id=self.applicationId).json()
 
     def upload(self, manifest):
-        log.info("Uploading manifest")
+        log.info("Uploading manifest: %s to application: %s (%s)" % (manifest.source, self.name, self.applicationId))
         self.manifest = manifest
         if router.public_api_in_use:
             return router.post_application_manifest(org_id=self.organizationId, app_id=self.applicationId,
