@@ -190,23 +190,6 @@ class PrivatePath(Router):
     @route("GET /organizations/{org_id}/zones{ctype}")
     def get_zones(self, org_id, cookies, ctype=".json"): pass
 
-    #CloudProvider
-    @play_auth
-    @route("GET /organizations/{org_id}/providers{ctype}")
-    def get_providers(self, org_id, cookies, ctype=".json"): pass
-
-    @play_auth
-    @route("POST /organizations/{org_id}/providers{ctype}")
-    def post_organization_provider(self, org_id, data, cookies, ctype=".json"): pass
-
-    @play_auth
-    @route("POST /organizations/{org_id}/providers/{prov_id}{ctype}")
-    def post_provider(self, org_id, prov_id, data, cookies, ctype=".json"): pass
-
-    @play_auth
-    @route("DELETE /organizations/{org_id}/providers/{prov_id}{ctype}")
-    def delete_provider(self, org_id, prov_id, cookies, data="{}", ctype=".json"): pass
-
     #Service
     @play_auth
     @route("GET /organizations/{org_id}/services{ctype}")
